@@ -201,31 +201,15 @@ def cloud_compute(cores=8, timeout=1800):
                                 'sizeMB': obj.get('__nerd_size_mb', '')
                             }
                         }
-                    
-                    # Special handling for very large binary data
-                    if isinstance(obj, bytes) and len(obj) > 5 * 1024 * 1024:  # > 5MB
-                        size_mb = len(obj) / (1024 * 1024)
-                        debug_print(f"Large binary data detected: {size_mb:.2f} MB")
-                        # Upload to cloud storage
-                        upload_result = upload_nerd_cloud_storage(obj)
-                        debug_print(f"Uploaded large binary data: {upload_result['dataId']}")
-                        # Return a reference that can be recognized on the cloud side
-                        return {
-                            'type': 'bytes_reference',
-                            'value': {
-                                'data_reference': upload_result['dataId'],
-                                's3Uri': upload_result.get('s3Uri', ''),
-                                'sizeMB': upload_result.get('sizeMB', size_mb)
-                            }
-                        }
 
                     # Standard serialization for everything else:
-                    # 1. Pickle the object to binary form (use protocol 4 for compatibility)
-                    pickled = pickle.dumps(obj, protocol=4)
+                    # 1. Pickle the object to binary form
+                    pickled = pickle.dumps(obj)
                     # 2. Compress the pickled data
                     compressed = zlib.compress(pickled)
                     # 3. Base64 encode the compressed data
                     encoded = base64.b64encode(compressed).decode('utf-8')
+                    debug_print(f"Serialized object size: {len(encoded) / (1024*1024):.2f} MB")
                     return {'type': 'data', 'value': encoded}
                 except Exception as e:
                     spinner.stop()
