@@ -1,6 +1,8 @@
 import requests
 import json
 import io
+import pickle
+import traceback
 from ...utils import debug_print
 from ...spinner import Spinner
 
@@ -70,13 +72,36 @@ def fetch_large_file(data_id, api_key):
 
         spinner.stop()
         print(f"✅ Large file downloaded successfully! Size: {size_mb}MB")
+        print(f"[DOWNLOAD_DEBUG] Download completed, content type: {content_type}")
+        print(f"[DOWNLOAD_DEBUG] Binary data size: {len(binary_data) / (1024 * 1024):.2f}MB")
 
+        # First try to deserialize as pickle if it's potentially a pickle file
+        if content_type in ('application/python-pickle', 'application/octet-stream'):
+            try:
+                print(f"[DOWNLOAD_DEBUG] Attempting pickle deserialization")
+                result = pickle.loads(binary_data)
+                print(f"[DOWNLOAD_DEBUG] Successfully deserialized pickled object of type: {type(result).__name__}")
+                
+                # Print additional information about the result for debugging
+                if hasattr(result, '__dict__'):
+                    print(f"[DOWNLOAD_DEBUG] Object attributes: {dir(result)[:20]}")
+                elif isinstance(result, dict):
+                    print(f"[DOWNLOAD_DEBUG] Dictionary keys: {list(result.keys())[:20] if result else 'empty'}")
+                elif hasattr(result, 'shape'):
+                    print(f"[DOWNLOAD_DEBUG] Object shape: {result.shape}")
+                
+                return result
+            except Exception as e:
+                print(f"[DOWNLOAD_DEBUG] Pickle deserialization failed: {str(e)}")
+                print(traceback.format_exc())
+                # Continue to try other formats if pickle fails
+        
         # Try to detect and parse specific content types
-        if content_type == 'application/json' or (
-            content_type == 'application/octet-stream' and _looks_like_json(binary_data)):
+        if content_type == 'application/json' or _looks_like_json(binary_data):
             try:
                 # Try to decode as JSON
                 decoded_text = binary_data.decode('utf-8')
+                print(f"[DOWNLOAD_DEBUG] Attempting JSON deserialization")
 
                 # Check if it's a JSON string that needs to be parsed twice
                 # (This happens when JSON is stored as a string inside JSON)
@@ -86,40 +111,48 @@ def fetch_large_file(data_id, api_key):
                     # First parse the outer JSON string
                     unescaped_json_str = json.loads(decoded_text)
                     # Then parse the inner JSON data
-                    return json.loads(unescaped_json_str)
+                    result = json.loads(unescaped_json_str)
+                    print(f"[DOWNLOAD_DEBUG] Successfully deserialized nested JSON")
+                    return result
                 else:
                     # Normal JSON, parse once
-                    return json.loads(decoded_text)
+                    result = json.loads(decoded_text)
+                    print(f"[DOWNLOAD_DEBUG] Successfully deserialized JSON")
+                    return result
             except (json.JSONDecodeError, UnicodeDecodeError) as e:
-                debug_print(f"Error parsing JSON: {e}")
-                # If it fails to parse as JSON, return the binary data
-                pass
+                print(f"[DOWNLOAD_DEBUG] JSON deserialization failed: {str(e)}")
+                # If it fails to parse as JSON, fall through to other methods
 
         # For text-based content types, try to decode as text
         if content_type.startswith('text/') or _looks_like_text(binary_data):
             try:
                 # Try to decode as text
                 text_data = binary_data.decode('utf-8')
+                print(f"[DOWNLOAD_DEBUG] Successfully decoded as text, length: {len(text_data)}")
 
                 # Check if the text looks like JSON
                 if (text_data.startswith('{') and text_data.endswith('}')) or \
                    (text_data.startswith('[') and text_data.endswith(']')):
                     try:
-                        return json.loads(text_data)
+                        result = json.loads(text_data)
+                        print(f"[DOWNLOAD_DEBUG] Text successfully parsed as JSON")
+                        return result
                     except json.JSONDecodeError:
-                        pass
+                        print(f"[DOWNLOAD_DEBUG] Text is not valid JSON")
 
                 return text_data
-            except UnicodeDecodeError:
-                # If it fails to decode as text, return the binary data
-                pass
+            except UnicodeDecodeError as e:
+                print(f"[DOWNLOAD_DEBUG] Text decoding failed: {str(e)}")
+                # If it fails to decode as text, fall through to binary
 
         # Return raw binary for other types
+        print(f"[DOWNLOAD_DEBUG] Returning raw binary data as no deserialization method succeeded")
         return binary_data
 
     except Exception as e:
         spinner.stop()
         print(f"❌ Error during large file download: {e}")
+        print(traceback.format_exc())
         raise
     finally:
         spinner.stop()
