@@ -3,22 +3,25 @@ import json
 import pickle
 from ...utils import debug_print
 from ...spinner import Spinner
+import traceback
 
-def upload_large_file(data_to_upload, api_key, storage_format=None):
+def upload_large_file(data_to_upload, metadata=None):
     """
     Handle upload of large files to the cloud storage
 
     Args:
         data_to_upload: The data to upload
-        api_key: The API key for authentication
-        storage_format: Format to store data (binary or json)
+        metadata: Optional metadata to include with the upload
 
     Returns:
         dict: Information about the uploaded data
     """
-    # Determine storage format if not specified
-    if storage_format is None:
-        storage_format = 'binary' if isinstance(data_to_upload, bytes) else 'json'
+    # Get the API key
+    from ..auth import get_api_key
+    api_key = get_api_key()
+    
+    # Determine storage format
+    storage_format = 'binary' if isinstance(data_to_upload, bytes) else 'pickle'
 
     # Set up the request
     spinner = Spinner("Getting presigned URL for large file upload...")
@@ -47,23 +50,23 @@ def upload_large_file(data_to_upload, api_key, storage_format=None):
         upload_url = upload_info['presignedUrl']
 
         # Convert data to binary if needed
-        binary_data = data_to_upload
-        if not isinstance(data_to_upload, bytes):
-            try:
-                if storage_format == 'json':
-                    try:
-                        binary_data = json.dumps(data_to_upload).encode('utf-8')
-                    except (TypeError, OverflowError):
-                        # If not JSON serializable, convert to string representation
-                        binary_data = str(data_to_upload).encode('utf-8')
-                else:
-                    # Use pickle for any complex objects
-                    binary_data = pickle.dumps(data_to_upload)
-            except Exception as e:
-                spinner.stop()
-                error_msg = f"Failed to serialize data: {e}"
-                print(f"❌ {error_msg}")
-                raise Exception(error_msg)
+        binary_data = None
+        try:
+            if isinstance(data_to_upload, bytes):
+                # Already in binary format
+                binary_data = data_to_upload
+                debug_print("Data is already in binary format")
+            else:
+                # Use pickle for any complex objects - maintain exact structure
+                debug_print(f"Pickling data of type: {type(data_to_upload).__name__}")
+                binary_data = pickle.dumps(data_to_upload, protocol=pickle.HIGHEST_PROTOCOL)
+                debug_print(f"Data pickled successfully, size: {len(binary_data) / (1024 * 1024):.2f}MB")
+        except Exception as e:
+            spinner.stop()
+            error_msg = f"Failed to serialize data: {e}"
+            debug_print(traceback.format_exc())
+            print(f"❌ {error_msg}")
+            raise Exception(error_msg)
 
         # Get data size for progress reporting
         data_size = len(binary_data)
@@ -73,11 +76,14 @@ def upload_large_file(data_to_upload, api_key, storage_format=None):
         spinner.update_message(f"Uploading {data_size_mb:.2f}MB to presigned URL...")
 
         # Upload using PUT method with the correct content-type
+        content_type = 'application/python-pickle' if storage_format == 'pickle' else 'application/octet-stream'
+        debug_print(f"Uploading with content-type: {content_type}")
+        
         upload_response = requests.put(
             upload_url,
             data=binary_data,
             headers={
-                'Content-Type': 'application/octet-stream'
+                'Content-Type': content_type
             }
         )
 
@@ -97,12 +103,14 @@ def upload_large_file(data_to_upload, api_key, storage_format=None):
             'dataId': upload_info['dataId'],
             's3Uri': upload_info['s3Uri'],
             'storageFormat': storage_format,
-            'sizeMB': f"{data_size_mb:.2f}"
+            'sizeMB': f"{data_size_mb:.2f}",
+            'contentType': content_type
         }
 
     except Exception as e:
         spinner.stop()
         print(f"❌ Error during large file upload: {e}")
+        debug_print(traceback.format_exc())
         raise
     finally:
         spinner.stop()
\ No newline at end of file
